@@ -1,13 +1,13 @@
 """Module with functions for 'terminal' subpackage."""
 
 from __future__ import annotations
-from pathlib import Path, PurePosixPath
+from pathlib import Path
 import subprocess
 import platform
 import importlib.util
 import sys
 
-from ..paths import PathLike, WslPath
+from ..paths import PathLike, WslPath, validate_path
 
 
 def is_wsl():
@@ -57,6 +57,7 @@ def terminal_do_command(
     verbose: bool = True,
     error_header: str = "",
     with_wsl: bool = False,
+    input_str: None | str = None,
 ) -> str:
     """Run command in terminal and process output.
 
@@ -68,12 +69,23 @@ def terminal_do_command(
         error_header (str, optional): If meet error, message at the beginning of message. Defaults to "".
         with_wsl (bool, optional): Prepend wsl prefix and edit command so it works. Path needs to be edited
             manually (for example with `wsl_pathlib` package). Defaults to False
+        input_str (None | str): Input inserted into terminal. It can be answer `y` for example if terminal needs
+            an confirmation. Defaults to None.
 
     Raises:
         RuntimeError: When process fails to finish or return non zero return code.
+
+    Example:
+        >>> res = terminal_do_command("python --version")
+        <BLANKLINE>
+        Python ...
+        <BLANKLINE>
     """
     error = "Terminal command crashed internally in subprocess and did not finished."
 
+    if cwd:
+        cwd = validate_path(cwd)
+
     if with_wsl:
         command = "wsl " + command
 
@@ -82,16 +94,21 @@ def terminal_do_command(
         if cwd:
             cwd = WslPath(cwd)
 
+    if input_str:
+        input_bytes = input_str.encode("utf-8")
+    else:
+        input_bytes = None
+
     try:
-        result = subprocess.run(command, shell=shell, cwd=cwd, capture_output=True)
+        result = subprocess.run(command, shell=shell, cwd=cwd, capture_output=True, input=input_bytes)
         if result.returncode == 0:
-            stdout = result.stdout.decode().strip("\r\n")
+            stdout = result.stdout.decode("utf-8").strip("\r\n")
             if verbose:
                 print(f"\n{stdout}\n")
             return stdout
         else:
-            stderr = result.stderr.decode().strip("\r\n")
-            stdout = result.stdout.decode().strip("\r\n")
+            stderr = result.stderr.decode("utf-8").strip("\r\n")
+            stdout = result.stdout.decode("utf-8").strip("\r\n")
             error = f"\n\nstderr:\n\n{stderr}\n\nstdout:\n\n{stdout}\n\n"
 
             raise TerminalCommandError("Return code is not 0.")
@@ -163,7 +180,7 @@ def which(name) -> None | Path:
 
     result = subprocess.run(command, shell=True, capture_output=True)
 
-    output = result.stdout.decode().rstrip("\r\n")
+    output = result.stdout.decode("utf-8").rstrip("\r\n")
 
     if "\r\n" in output:
         output = output.split("\r\n")[0]
